"use client";
import { useRef, useState, useEffect } from "react";
import { message, Tabs } from "antd";
import { css, cx } from "antd-style";
import { getUserInfo,updateUserInfo, userPassword, getUserBalance } from "@/api/client";
import { useGlobalContext } from "@/providers/GlobalProvider";
import { useTheme } from "next-themes";
import {
  RiAiGenerateText,
  RiAiGenerate2,
  RiBrushAiLine,
  RiExchangeCnyLine,
} from "react-icons/ri";

const UserCenter = () => {
  const themeBig = useTheme();
  const { changeMenuIndex,uploadUserInfoState, changeUploadUserInfoState } = useGlobalContext();
  const [userName, setUserName] = useState<string>("");
  const [nickName_static, setNickName_static] = useState<string>("");
  const [nickName, setNickName] = useState<string>("");
  const [phone, setPhone] = useState<string>("");
  const [email, setEmail] = useState<string>("");
  const [balance, setBalance] = useState<number>(0);

  const [oldPassword, setOldPassword] = useState<string>("");
  const [newPassword, setNewPassword] = useState<string>("");

  const inputRef_nickName = useRef<HTMLInputElement>(null);
  const inputRef_phone = useRef<HTMLInputElement>(null);
  const inputRef_email = useRef<HTMLInputElement>(null);

  const inputRef_oldPassword = useRef<HTMLInputElement>(null);
  const inputRef_newPassword = useRef<HTMLInputElement>(null);

  const handleSaveUserInfo = (e: React.FormEvent) => {
    e.preventDefault();
    if (nickName) {
      if (phone) {
        if (email) {
          updateUserInfo({nickname:nickName, mobile: phone, email: email }).then(
            (data) => {
              message.success("用户信息更新成功！");
              changeUploadUserInfoState(!uploadUserInfoState);
            }
          );
        } else {
          inputRef_email.current?.focus();
        }
      } else {
        inputRef_phone.current?.focus();
      }
    } else {
      inputRef_nickName.current?.focus();
    }
  };

  const handleUpdatePassword = (e: React.FormEvent) => {
    e.preventDefault();
    if (oldPassword) {
      if (newPassword) {
        userPassword({ password: oldPassword, password2: newPassword }).then(
          (data) => {
            message.success("密码更新成功");
            setOldPassword("");
            setNewPassword("");
          }
        );
      } else {
        inputRef_newPassword.current?.focus();
      }
    } else {
      inputRef_oldPassword.current?.focus();
    }
  };

  const logout = () => {
    localStorage.removeItem("chat-used-list-type");
    localStorage.removeItem("chat-used-agent-id");
    localStorage.removeItem("chat-used-conversation-id");
    localStorage.removeItem("chat-model-list");
    localStorage.removeItem("session");
    message.success("账户退出成功！");
    setTimeout(() => {
      window.location.href = "/";
    }, 600);
  };

  useEffect(() => {
    changeMenuIndex(0);
    getUserInfo().then((data) => {
      if (data.code == 0) {
        setUserName(data.data.username);
        setNickName_static(data.data.nickname);
        setNickName(data.data.nickname);
        setPhone(data.data.mobile);
        setEmail(data.data.email);
      }
    });
    getUserBalance().then((data) => {
      if (data.code == 0) {
        setBalance(data.data.balance);
      }
    });
  }, [uploadUserInfoState]);

  return (
    <>
      <div className="flex flex-col md:flex-row p-5">
        <div className="w-full md:w-72 flex-none">
          <h2 className="mb-4">
            <span className="text-2xl text-[#0061ff]">我的信息</span>
            <span
              className="text-sm text-red-700 float-right cursor-pointer bg-gray-200 px-3 py-2 rounded"
              onClick={logout}
            >
              退出登录
            </span>
          </h2>
          <div className="text-center text-sm mt-10">
            <img
              className="w-40 h-40 object-cover rounded mx-auto"
              src="/images/avatar.png"
              alt="avatar"
            />
            <div className="mt-4 text-xl">{nickName_static}</div>
            <div className="mt-3 text-gray-400">
              {userName}
            </div>
            <div className="mt-3 text-gray-600 text-left">
              我是一台基于深度学习和自然语言处理技术的 AI
              机器人，旨在为用户提供高效、精准、个性化的智能服务。
            </div>
          </div>
          <div className="mt-10 text-sm">
            <div className="text-xl text-[#0061ff]">我的成就</div>
            <div className="mt-3 pl-3">
              <span className="text-[#0061ff] pr-3">基础模型使用:</span>
              {balance} 积分
            </div>
            <div className="mt-3 pl-3">
              <span className="text-[#0061ff] pr-3">高级模型使用:</span>0 积分
            </div>
            <div className="mt-3 pl-3">
              <span className="text-[#0061ff] pr-3">基础模型使用:</span>0 Token
            </div>
            <div className="mt-3 pl-3">
              <span className="text-[#0061ff] pr-3">高级模型使用:</span>0 Token
            </div>
            <div className="mt-3 pl-3">
              <span className="text-[#0061ff] pr-3">专业绘画使用:</span>0 积分
            </div>
          </div>
        </div>
        <div className="grow mt-10 md:mt-0 md:pl-16">
          <div className="border-b border-gray-200 dark:border-slate-700 pb-5">
            <h2 className="text-xl font-bold">个人中心</h2>
            <div className="text-sm mt-3 dark:text-gray-400">
              编辑个人信息、查看更多详情
            </div>
          </div>
          <div className="mt-6">
            <Tabs defaultActiveKey="1">
              <Tabs.TabPane tab="我的积分" key="1">
                <div className="border border-gray-200 dark:border-slate-700 p-5 rounded-sm">
                  <div className="text-lg dark:text-white">用户积分余额</div>
                  <div className="py-5">
                    <div className="flex flex-wrap -m-2">
                      <div className="p-2 md:w-1/2 w-full">
                        <div className="h-full flex items-center border-gray-200 dark:border-slate-700 border p-4 rounded">
                          <div className="mr-4 text-4xl font-bold text-center">
                            <RiAiGenerateText className="text-[#0061ff]" />
                            <p className=" dark:text-white">{balance}</p>
                          </div>
                          <div className="flex-grow">
                            <h2 className="text-[#0061ff] title-font font-medium text-xl">
                              基础模型余额
                            </h2>
                            <p className="text-gray-500 mt-3">
                              每次对话根据模型消费不同积分！
                            </p>
                          </div>
                        </div>
                      </div>
                      <div className="p-2 md:w-1/2 w-full">
                        <div className="h-full flex items-center border-gray-200 dark:border-slate-700 border p-4 rounded">
                          <div className="mr-4 text-4xl font-bold text-center">
                            <RiAiGenerate2 className="text-[#0061ff]" />
                            <p className=" dark:text-white">{balance}</p>
                          </div>
                          <div className="flex-grow">
                            <h2 className="text-[#0061ff] title-font font-medium text-xl">
                              高级模型余额
                            </h2>
                            <p className="text-gray-500 mt-3">
                              每次对话根据模型消费不同积分！
                            </p>
                          </div>
                        </div>
                      </div>
                      <div className="p-2 md:w-1/2 w-full">
                        <div className="h-full flex items-center border-gray-200 dark:border-slate-700 border p-4 rounded">
                          <div className="mr-4 text-4xl font-bold text-center">
                            <RiBrushAiLine className="text-[#0061ff]" />
                            <p className=" dark:text-white">{balance}</p>
                          </div>
                          <div className="flex-grow">
                            <h2 className="text-[#0061ff] title-font font-medium text-xl">
                              专业绘画余额
                            </h2>
                            <p className="text-gray-500 mt-3">
                              根据画图动作消耗不同的积分！
                            </p>
                          </div>
                        </div>
                      </div>
                      <div className="p-2 md:w-1/2 w-full">
                        <div className="h-full flex items-center border-gray-200 dark:border-slate-700 border p-4 rounded">
                          <div className="mr-4 text-4xl font-bold text-center">
                            <RiExchangeCnyLine className="text-[#0061ff]" />
                            <p className=" dark:text-white">{balance}</p>
                          </div>
                          <div className="flex-grow">
                            <h2 className="text-[#0061ff] title-font font-medium text-xl">
                              会员套餐购买
                            </h2>
                            <p className="text-gray-500 mt-3">
                              <a href="/vip">去购买</a>
                            </p>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
                <div className="border border-gray-200 dark:border-slate-700 p-5 rounded-sm mt-6">
                  <div className="text-lg dark:text-white">充值记录</div>
                  <div className="py-5 overflow-x-auto">
                    <table className="border border-slate-200 dark:border-slate-700 text-center w-[960px] md:w-full">
                      <thead className="border-b border-slate-200 dark:border-slate-700 bg-gray-100 dark:bg-gray-800 h-12 dark:text-gray-300">
                        <tr>
                          <th className="">订单编号</th>
                          <th className="">充值类型</th>
                          <th className="">基础模型额度</th>
                          <th className="">高级模型额度</th>
                          <th className="">专业绘画额度</th>
                          <th className="">有效期</th>
                          <th className="">充值时间</th>
                        </tr>
                      </thead>
                      <tbody>
                        <tr className="h-14 dark:text-gray-300">
                          <td className="">d3dadc220</td>
                          <td className="">注册赠送</td>
                          <td className="">30</td>
                          <td className="">30</td>
                          <td className="">0</td>
                          <td className="">永久</td>
                          <td className="">2024-12-10 09:50:52</td>
                        </tr>
                      </tbody>
                    </table>
                  </div>
                </div>
              </Tabs.TabPane>
              <Tabs.TabPane tab="个人信息" className="dark:text-white" key="2">
                <div className="border border-gray-200 dark:border-slate-700 p-5 rounded-sm">
                  <div className="text-lg dark:text-white">
                    用户账户信息设置
                  </div>
                  <div className="py-5">
                    <div className="flex flex-col items-center justify-center">
                      <div className="w-full">
                        <div className="flex w-full flex-col mx-auto sm:space-x-4 sm:space-y-0 space-y-4 sm:px-0 items-end">
                          <div className="relative flex-grow w-full">
                            <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                              昵称
                            </label>
                            <input
                              type="text"
                              autoComplete="new-password"
                              className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-slate-700 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                              ref={inputRef_nickName}
                              value={nickName}
                              onChange={(e) => setNickName(e.target.value)}
                            />
                          </div>
                          <div className="relative flex-grow w-full">
                            <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                              手机号码
                            </label>
                            <input
                              type="phone"
                              autoComplete="new-password"
                              className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-slate-700 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                              ref={inputRef_phone}
                              value={phone}
                              onChange={(e) => setPhone(e.target.value)}
                            />
                          </div>
                          <div className="relative flex-grow w-full">
                            <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                              邮箱
                            </label>
                            <input
                              type="email"
                              autoComplete="new-password"
                              className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-slate-700 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                              ref={inputRef_email}
                              value={email}
                              onChange={(e) => setEmail(e.target.value)}
                            />
                          </div>
                          <div className="relative flex-grow w-full pt-6 text-center">
                            <button
                              className="text-white global-bg-color border-0 py-2 px-12 focus:outline-none hover:bg-indigo-600 rounded-full"
                              onClick={handleSaveUserInfo}
                            >
                              保存
                            </button>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </Tabs.TabPane>
              <Tabs.TabPane tab="账户安全" key="3">
                <div className="border border-gray-200 dark:border-slate-700 p-5 rounded-sm">
                  <div className="text-lg dark:text-white">
                    用户账户信息设置
                  </div>
                  <div className="py-5">
                    <div className="flex flex-col items-center justify-center">
                      <div className="w-full">
                        <div className="flex w-full flex-col mx-auto sm:space-x-4 sm:space-y-0 space-y-4 sm:px-0 items-end">
                          <div className="relative flex-grow w-full">
                            <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                              旧密码
                            </label>
                            <input
                              type="password"
                              autoComplete="new-password"
                              className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-slate-700 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                              ref={inputRef_oldPassword}
                              value={oldPassword}
                              onChange={(e) => setOldPassword(e.target.value)}
                            />
                          </div>
                          <div className="relative flex-grow w-full">
                            <label className="leading-7 text-sm text-gray-600 dark:text-gray-400">
                              新密码
                            </label>
                            <input
                              type="password"
                              autoComplete="new-password"
                              className="w-full bg-gray-50 dark:bg-[#202123] bg-opacity-50 rounded border border-gray-300 dark:border-slate-700 focus:border-blue-950 focus:bg-transparent focus:ring-2 focus:ring-blue-950 text-base outline-none text-gray-700 py-1 px-3 leading-8 transition-colors duration-200 ease-in-out"
                              ref={inputRef_newPassword}
                              value={newPassword}
                              onChange={(e) => setNewPassword(e.target.value)}
                            />
                          </div>
                          <div className="relative flex-grow w-full pt-6 text-center">
                            <button
                              className="text-white global-bg-color border-0 py-2 px-12 focus:outline-none hover:bg-indigo-600 rounded-full"
                              onClick={handleUpdatePassword}
                            >
                              保存
                            </button>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </Tabs.TabPane>
            </Tabs>
          </div>
        </div>
      </div>
    </>
  );
};

export default UserCenter;
