"use client";
import { useRef, useContext, useEffect, useState } from "react";
import { useGlobalContext } from "@/providers/GlobalProvider";
import { userLogin } from "@/api/client";
import { message } from "antd";
import { setUserSession } from "@/utils/user";
import { RiCloseFill } from "react-icons/ri";

export default function Login() {
  const { loginShow, changeLoginShow } = useGlobalContext();
  const [email, setEmail] = useState<string>("");
  const [password, setPassword] = useState<string>("");

  const inputRef_email = useRef<HTMLInputElement>(null);
  const inputRef_password = useRef<HTMLInputElement>(null);

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    if (email) {
      if (password) {
        userLogin({ username: email, password: password }).then((data) => {
          if (data.code == 0) {
            message.success("登录成功");
            setUserSession(data.data.token, data.data.expireTime);
            changeLoginShow(false);
          } else {
            message.error("用户名或密码错误");
          }
        });
      } else {
        inputRef_password.current?.focus();
      }
    } else {
      inputRef_email.current?.focus();
    }
  };

  const closeLoginBox = () => {
    changeLoginShow(!loginShow);
    setEmail("");
    setPassword("");
  };

  return (
    <>
      {loginShow && (
        <div className="login-box">
          <div className="login-mask"></div>
          <div className="login-div dark:bg-gray-800 w-11/12 md:w-128">
            <h4 className="text-2xl text-center dark:text-blue-50">登　录</h4>
            <ul className="flex justify-around mt-1 mb-3"></ul>

            <div className="login pt-2 h-92.5 rounded-lg bg-white dark:bg-gray-800 dark:opacity-75">
              <div>
                <div className="mt-8 px-6">
                  <div className="flex items-center justify-between h-13 px-2.5 py-2 rounded bg-gray-100 dark:bg-gray-900">
                    <input
                      ref={inputRef_email}
                      className="flex-1 h-full"
                      type="text"
                      placeholder="请输入登录账户"
                      value={email}
                      onChange={(e) => setEmail(e.target.value)}
                      autoComplete="new-password"
                    />
                  </div>
                </div>
                <div className="mt-5 px-6">
                  <div className="flex items-center justify-between h-13 px-2.5 py-2 rounded bg-gray-100 dark:bg-gray-900">
                    <input
                      ref={inputRef_password}
                      className="flex-1 h-full"
                      type="password"
                      placeholder="请输入登录密码"
                      value={password}
                      onChange={(e) => setPassword(e.target.value)}
                      autoComplete="new-password"
                    />
                  </div>
                  <p className="h-5 mt-2 px-2.5 text-red-500"></p>
                </div>
                <div className="mt-4 text-center text-gray-400">
                  <label className="text-gray-500 dark:text-gray-700">
                    同意
                  </label>
                  <a
                    href="/"
                    className="text-gray-600 hover:text-[#0061ff] mx-1"
                  >
                    用户协议
                  </a>
                  <label className="text-gray-500 dark:text-gray-700">和</label>
                  <a
                    href="/"
                    className="text-gray-600 hover:text-[#0061ff] mx-1"
                  >
                    隐私政策
                  </a>
                </div>
                <div className="mt-3 px-8">
                  <button
                    className="block w-full h-12 rounded text-base text-white global-bg-color focus:outline-none focus:ring sm:mt-6 transition ease-in-out hover:-translate-y-1 hover:scale-105 duration-300"
                    onClick={handleSubmit}
                  >
                    登 录
                  </button>
                </div>
              </div>
            </div>

            <RiCloseFill
              className="close absolute right-2.5 top-2.5 w-7 h-7 text-gray-600 dark:text-gray-300 cursor-pointer transform duration-500 ease-in-out hover:scale-110"
              onClick={closeLoginBox}
            ></RiCloseFill>
          </div>
        </div>
      )}
    </>
  );
}
