import React from 'react';
import { NextUIProvider } from "@nextui-org/react";
import { ThemeProvider as NextThemesProvider } from "next-themes";
import FullLoading from "@/components/FullLoading"; // 全局 Loading
import Header from "@/components/Header"; // 头部布局
import Menu from "@/components/Menu"; // 菜单
import H5Menu from "@/components/Menu_H5"; // 菜单
import Login from "@/components/Login";

export function ThemeProvider({ children }: { children: React.ReactNode }) {
  return (
    <>
      <NextUIProvider>
        <NextThemesProvider
          attribute="class"
          defaultTheme={process.env.DEFAULT_THEME}
        >
          <FullLoading />
          <div className="h-screen w-full flex flex-col">
            <Header name={process.env.SITE_TITLE || "AI智能体广场"} />
            <div className="flex justify-between items-center bg-slate-200 dark:bg-[#000] md:py-3">
              <div className="shadow-md mx-2 bg-[#ffffff] dark:bg-[#202123] rounded-md p-2  overflow-auto scroll-smooth hidden md:block w-28 h-calc-5"  >
                <Menu />
              </div>
              <div className="block md:hidden">
                <H5Menu />
              </div>
                <div className="relative shadow-md md:mr-2 bg-[#ffffff] dark:bg-[#202123] md:rounded-md overflow-auto scroll-smooth w-full grow h-calc-8 md:h-calc-5">
                <main>{children}</main>
                </div>
            </div>
          </div>
        </NextThemesProvider>
      </NextUIProvider>
      <Login />
    </>
  );
}
