/**
 * 分类列表请求参数
 * 
 * @interface CategoryListParams
 * @property {number} page - 页数
 * @property {number} pageSize - 每页记录数
 */
export interface CategoryListParams {
    page: number;
    pageSize: number;
}

/**
 * 分类列表响应结果
 * 
 * @interface CategoryListResult
 * @property {number} id - ID
 * @property {number} createdAt - 创建时间（时间戳）
 * @property {number} updatedAt - 更新时间（时间戳）
 * @property {string} name - 令分类名
 * @property {number} organizationId - 分组ID
 */
export interface CategoryListResult {
    id: number;
    createdAt: number;
    updatedAt: number;
    name: string;
    organizationId: number;
}

/**
 * 智能体列表请求参数
 * 
 * @interface EmployeeSearchParams
 * @property {number} page - 页数
 * @property {number} pageSize - 每页记录数
 * @property {number} categoryId - 分类ID
 * @property {string} title - 搜索词
 */
export interface EmployeeSearchParams {
    page: number;
    pageSize: number;
    categoryId: number;
    title: string;
}

/**
 * 智能体详情请求参数
 * 
 * @interface EmployeeDetailParams
 * @property {number} id - ID
 */
export interface EmployeeDetailParams {
    id: number;
}

/**
 * 智能体列表响应结果
 * 
 * @interface EmployeeSearchResult
 * @property {number} id - 唯一标识符
 * @property {number} createdAt - 创建时间（时间戳）
 * @property {number} updatedAt - 更新时间（时间戳）
 * @property {string} title - 标题
 * @property {string} avatar - 头像URL
 * @property {string} tags - 标签
 * @property {number} hireCount - 雇佣次数
 * @property {number} serviceCount - 服务次数
 * @property {number} achievementCount - 完成任务数
 * @property {number} categoryId - 分类ID
 * @property {string} intro - 简介
 * @property {string} estimate - 描述
 * @property {string} skill - 技能集
 * @property {string} abilityType - 能力类型
 * @property {string} scene - 适用场景
 * @property {any} sceneList - 场景列表
 * @property {string} switchIn - 可切换场景编号
 * @property {any} switchInList - 可切换场景列表
 * @property {any} tutorial - 教程信息
 * @property {string} videoUrl - 介绍视频
 * @property {any} workExperience - 工作经验
 * @property {any} apiBase - API基础信息
 * @property {any} apiKey - API密钥
 * @property {any} aiInfo - AI信息
 * @property {any} showChat - 展示聊天功能
 * @property {any} isVip - 否是VIP
 * @property {any} chatUrl - 聊天链接
 */
export interface EmployeeSearchResult {
    id: number;
    createdAt: number;
    updatedAt: number;
    title: string;
    avatar: string;
    tags: string;
    hireCount: number;
    serviceCount: number;
    achievementCount: number;
    categoryId: number;
    intro: string;
    estimate: string;
    skill: string;
    abilityType: string;
    scene: string;
    sceneList: any | null;
    switchIn: string;
    switchInList: any | null;
    tutorial: any | null;
    videoUrl: string;
    workExperience: any | null;
    apiBase: any | null;
    apiKey: any | null;
    aiInfo: any | null;
    showChat: any | null;
    isVip: any | null;
    chatUrl: any | null;
}

/**
 * 用户登录请求参数
 * 
 * @interface UserLoginParams
 * @property {string} username - 用户名
 * @property {string} password - 密码
 */
export interface UserLoginParams {
    username?: string;
    password?: string;
}

/**
 * 用户登录响应结果
 * 
 * @interface UserLoginResult
 * @property {string} id - 用户唯一标识符
 * @property {string} token - 用户登录令牌
 * @property {string} username - 用户名
 * @property {number} expireTime - 令牌过期时间（时间戳）
 */
export interface UserLoginResult {
    id: string;
    token: string;
    username: string;
    expireTime: number;
}

/**
 * 用户修改密码请求参数
 * 
 * @interface UserPasswordParams
 * @property {string} password - 新密码
 * @property {string} password2 - 确认密码
 */
export interface UserPasswordParams {
    password?: string;
    password2?: string;
}

/**
 * 用户修改个人信息请求参数
 * 
 * @interface UserInfoParams
 * @property {string} nickname - 昵称
 * @property {string} mobile - 手机号码
 * @property {string} email -邮箱
 */
export interface UserInfoParams {
    nickname: string;
    mobile: string;
    email: string;
}


/**
 * 获取用户信息响应结果
 * 
 * @interface UserInfoResult
 * @property {string} id - ID
 * @property {string} avatar - 头像
 * @property {string} username - 用户名
 * @property {string} nickname - 昵称
 * @property {number} status - 状态（1代表正常，非1代表不可用）
 * @property {string} mobile - 手机号
 * @property {string} email - 邮箱
 */
export interface UserInfoResult {
    id: string;
    avatar: string;
    username: string;
    nickname: string;
    status: number;
    mobile: string;
    email: string;
}

/**
 * 获取用户积分响应结果
 * 
 * @interface UserBalanceResult
 * @property {number} balance - 积分
 */
export interface UserBalanceResult {
    balance: number;
}


/**
 * 聊天提交内容请求参数
 * 
 * @interface ChatSubmitParams
 * @property {string} content - 聊天内容
 * @property {string} conversationId - 会话ID
 */
export interface ChatSubmitParams {
    content: string;
    conversationId: string;
}

/**
 * 聊天提交内容响应结果
 * 
 * @interface ChatSubmitResult
 * @property {string} id - 消息ID
 * @property {string} message_id - 消息ID
 * @property {number} session_id - 
 * @property {string} conversation_id - 代表会话ID
 * @property {string} answer - 回答的内容
 * @property {boolean} finish - 是否已完成
 * @property {boolean} need_pay - 是否需要付费
 * @property {boolean} need_login - 是否需要登录
 */
export interface ChatSubmitResult {
    id: string;
    message_id: string;
    session_id: number;
    conversation_id: string;
    answer: string;
    finish: boolean;
    need_pay: boolean;
    need_login: boolean;
}

/**
 * 查询会话下的聊天历史请求参数
 * 
 * @interface ChatMessageParams
 * @property {string} conversationId - 会话ID
 * @property {string} firstId - 当前页第一条聊天记录的 ID，默认为空
 * @property {number} limit - 一次请求返回多少条聊天记录
 * @property {number} agentId - 智能体ID
 */
export interface ChatMessageParams {
    conversationId: string;
    firstId: string;
    limit: number;
    agentId: number;
}

/**
 * 查询会话下的聊天历史响应结果
 * 
 * @interface ChatMessageResult
 * @property {string} id - 记录ID
 * @property {string} conversationId - 会话ID
 * @property {string} query - 问题
 * @property {string} answer - 回答
 * @property {any} inputs - 输入参数
 * @property {number} createdAt - 时间
 */
export interface ChatMessageResult {
    id: string;
    conversationId: string;
    query: string;
    answer: string;
    inputs: any;
    createdAt: number;
}

/**
 * 聊天会话列表请求参数
 * 
 * @interface ChatSessionParams
 * @property {number} agentId - 智能体ID
 * @property {string} last_id - 当前页最后面一条记录的 ID
 * @property {string} limit - 一次请求返回多少条记录
 */
export interface ChatSessionParams {
    agentId: number;
    last_id: string;
    limit: number;
}

/**
 * 聊天会话列表响应结果
 * 
 * @interface ChatSessionResult
 * @property {string} id - 记录ID
 * @property {string} name - 名称
 * @property {number} createdAt - 时间
 * @property {any} inputs - 输入参数
 */
export interface ChatSessionResult {
    id: string;
    name: string;
    createdAt: number;
    inputs: any;
}

/**
 * 聊天会话删除请求参数
 * 
 * @interface ChatSessionDeleteParams
 * @property {string} conversationId - 会话ID
 * @property {number} agentId - 智能体ID
 */
export interface ChatSessionDeleteParams {
    conversationId: string;
    agentId: number;
}

/**
 * 聊天会话重命名请求参数
 * 
 * @interface ChatSessionRenameParams
 * @property {string} conversationId - 会话ID
 * @property {number} agentId - 智能体ID
 * @property {string} name - 名称
 */
export interface ChatSessionRenameParams {
    conversationId: string;
    agentId: number;
    name: string;
}